General parameters
==================

List bellow shows required parameters with default values.

.. toctree::
   :maxdepth: 2
   :titlesonly:
   
   Format
   Version monitoring <Version_monitoring>
   Language
